UHLG: Unit Half Logistic-Geometry distribution

UHLGR Documentation

Unit Half Logistic-Geometry distribution

Description

The Unit Half Logistic-Geometry family

Usage

UHLG(mu.link = "log")

Arguments

mu.link

defines the mu.link, with "log" link as the default for the mu parameter.

Details

The Unit Half Logistic-Geometry distribution with parameter mu, has density given by

f(x| \mu) = \frac{2 \mu}{(\mu+(2-\mu)x)^2}

for 0 < x < 1 and \mu > 0.

Value

Returns a gamlss.family object which can be used to fit a UHLG distribution in the gamlss() function.

Author(s)

Juan Diego Suarez Hernandez, jsuarezhe@unal.edu.co

References

Ramadan, A. T., Tolba, A. H., & El-Desouky, B. S. (2022). A unit half-logistic geometric distribution and its application in insurance. Axioms, 11(12), 676.

See Also

dUHLG

Examples

# Example 1
# Generating some random values with
# known mu
y <- rUHLG(n=500, mu=7)

# Fitting the model
library(gamlss)
mod1 <- gamlss(y~1, family=UHLG,
               control=gamlss.control(n.cyc=500, trace=FALSE))

# Extracting the fitted values for mu, sigma and nu
# using the inverse link function
exp(coef(mod1, what="mu"))

# Example 2
# Generating random values under some model

# A function to simulate a data set with Y ~ UHLG
gendat <- function(n) {
  x1 <- runif(n, min=0.4, max=0.6)
  x2 <- runif(n, min=0.4, max=0.6)
  mu    <- exp(-0.5 + 3*x1 - 2.5*x2)
  y <- rUHLG(n=n, mu=mu)
  data.frame(y=y, x1=x1, x2=x2)
}

datos <- gendat(n=5000)

mod2 <- gamlss(y~x1+x2,
               family=UHLG, data=datos,
               control=gamlss.control(n.cyc=500, trace=TRUE))
summary(mod2)

ZeroOneDists documentation built on March 7, 2026, 1:07 a.m.